<?php
/**
*
* @package National Flags 
* @version $Id: functions_flag.php
* @copyright (c) 2010 RMcGirr83
* @copyright (c) 2009 Anybloodyid
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* @ignore
*/
if (!defined('IN_PHPBB'))
{
	exit;
}


 
function check_for_file()
{
	global $user, $phpEx, $phpbb_root_path;
	
	$lang_path = $phpbb_root_path . '/language/' . $user->data['user_lang'] . '/';
	$file = 'flag_lang' . $phpEx;
	// check for the lang file being there
	if (file_exists($lang_path . $file))
	{
		return true;
	}
	return false;
}
				
/**
 * Get user flag
 *
 * @param int $flag_id
 * @return string flag_img
 */				
function get_user_flag($flag_id = false)
{
   global $db, $config, $phpbb_root_path, $cache, $user;
   
   if (($user_flags = $cache->get('_user_flags')) === false)
   {
	   $user_flags = array();

	  $sql = 'SELECT flag_id, flag_name, flag_image
		 FROM ' . FLAGS_DATA_TABLE . '
	  ORDER BY flag_id';
	  $result = $db->sql_query($sql);

	  while ($row = $db->sql_fetchrow($result))
	  {
		 $user_flags[$row['flag_id']] = array(
			'flag_id'      => $row['flag_id'],
			'flag_name'     => $row['flag_name'],
			'flag_image'   => $row['flag_image'],
		 );
	  }
	  $db->sql_freeresult($result);

	  // cache this data for ever, can only change in ACP
	  $cache->put('_user_flags', $user_flags);
   }
   if ($flag_id)
   {
		$check = check_for_file();
		if($check)
		{
			$user->add_lang('mods/flag_lang');
		}
	
		$flag_name = htmlspecialchars($user_flags[$flag_id]['flag_name']);

		if(isset($user->lang[strtoupper('flag_' . $user_flags[$flag_id]['flag_name'])]))
		{
			$flag_name = htmlspecialchars($user->lang[strtoupper('flag_' . $user_flags[$flag_id]['flag_name'])]);
		}

		//get the display type
		$display = $config['flag_type'];
		if ($display == USER_FLAG_TEXT)//Text only
		{
			$flag_img = $flag_name;
		}
		elseif ($display == USER_FLAG_IMAGE)//Image
		{
			$flag_img = '<img src="' . $phpbb_root_path . 'images/flags/' . $user_flags[$flag_id]['flag_image'] . '" alt="'. $flag_name . '" title="'. $flag_name . '" class="tipTip" style="vertical-align:middle;" />';
		}
		else// it's not 1 or 2 so it must be 3 which is both
		{
			$flag_img = '<img src="' . $phpbb_root_path . 'images/flags/' . $user_flags[$flag_id]['flag_image'] . '" alt="'. $flag_name . '" title="'. $flag_name . '" class="tipTip" style="vertical-align:middle;" />' . $flag_name;
		}
		return $flag_img;
	}
	return;
}
					
/**
 * Get list_all_flags
 *
 * @param int $flag_id
 * @return string flag_options
 */
 
function list_all_flags($flag_id)
{
	global $db, $user;
	
	$sql = 'SELECT flag_id, flag_name, flag_image
		FROM ' . FLAGS_DATA_TABLE . '
	ORDER BY flag_name';
	$result = $db->sql_query($sql);
	$check = check_for_file();
	if($check)
	{
		$user->add_lang('mods/flag_lang');
	}
	
	$flag_options = '<option value="0">' . $user->lang['FLAG_EXPLAIN'] . '</option>';
	while ($row = $db->sql_fetchrow($result))
	{
		$flag_name = $row['flag_name'];
		if(isset($user->lang[strtoupper('flag_' . $row['flag_name'])]))
		{
			$flag_name = $user->lang[strtoupper('flag_' . $row['flag_name'])];
		}
		$selected = ($row['flag_id'] == $flag_id) ? ' selected="selected"' : '';
		$flag_options .= '<option value="' . $row['flag_id'] . '" ' . $selected . '>' . $flag_name . '</option>';
	}
	$db->sql_freeresult($result);
	
	return $flag_options;
}

/**
 * Get top_flags
 */
function top_flags()
{
	global $db, $cache, $template, $user, $phpbb_root_path, $phpEx;

	if (($top_flags = $cache->get('_top_flags')) === false)
	{
	    $top_flags = array();	
		$sql = 'SELECT u.user_flag, COUNT(u.user_flag) AS fnum, f.flag_id
			FROM ' . USERS_TABLE . ' u
			LEFT JOIN ' . FLAGS_DATA_TABLE  . " f ON u.user_flag = f.flag_id
		WHERE u.user_type IN (" . USER_NORMAL . ', ' . USER_FOUNDER . ") AND u.user_flag > 0
		GROUP BY u.user_flag
		ORDER BY fnum DESC, f.flag_name ASC";
		$result = $db->sql_query_limit($sql, 10);

		while ($row = $db->sql_fetchrow($result))
		{
			$top_flags[] = array(
				'flag_id'		=> $row['flag_id'],
				'flag_count'	=> $row['fnum'],
				'flag_image'	=> get_user_flag($row['user_flag']),
			);
		}
		$db->sql_freeresult($result);
		// cache this data for 15 minutes
		$cache->put('_top_flags', $top_flags, 900);
	}		
	$count = count($top_flags);
	if($count)
	{
		foreach ($top_flags as $top_flag)
		{
			$flag_url = append_sid("{$phpbb_root_path}flag_users.$phpEx", 'fid=' . (int) $top_flag['flag_id']);
			$template->assign_block_vars('fnum', array(
				'FLAG' 			=> '<a href="' . $flag_url . '" class="tipTip">' . $top_flag['flag_image'] . '</a>',
				'L_FLAG_USERS'	=> $top_flag['flag_count'] == 1 ? sprintf($user->lang['FLAG_USER'], $top_flag['flag_count']) : sprintf($user->lang['FLAG_USERS'], $top_flag['flag_count']),
			));
		}
		$template->assign_vars(array(
			'S_FLAGS_FOUND'	=> true,
			'L_TOP_FLAG_TITLE'	=> sprintf($user->lang['TOP_FLAG_TITLE'], $count),
			'U_FLAGS'	=> append_sid("{$phpbb_root_path}flag_users.$phpEx", 'mode=flags'),
		));
	}

	return;
}	
?>